/**
 * Parsing routines for the DCC Monitor management protocol.
 *
 * This file is part of DCC Monitor.
 *
 * Copyright 2007, 2008 Peter Lebbing <peter@digitalbrains.com>
 *
 * DCC Monitor is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * DCC Monitor is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DCC Monitor.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdio.h>
#include "global.h"
#include "tests/test_dispatch.h"
#include "display.h"
#include "manag_proto.h"

/**
 * Dump the packet contents if Management protocol verbosity is set
 */
static void dump_hex_data_if_verbose (struct s_frame *frame) {
  if (verbosity & VERB_MANAG) {
    dump_hex_data (frame);
  }
}

/**
 * Parses the management frame and displays it on stdout
 */
int parse_manag (struct s_frame *frame) {

  start_output_line (frame);

  if (frame->len == 0) {
    // Empty management frames are not defined
 
    printf (": Unknown management data!\n");
    dump_hex_data (frame);
    return 0;
  }

  if (frame->len == 1) {
    // One-byte frame

    switch (frame->data[0]) {
      case 0:
        printf (": Hello\n");
        dump_hex_data_if_verbose (frame);
        return 0;

      case 1:
        printf (": Overflow on monitored bus!\n");
        dump_hex_data_if_verbose (frame); 
        return 0;

      case 2:
        printf (": Malformed packet received on incoming daisy-chain!\n");

        dump_hex_data_if_verbose (frame); 
        return 0;

      case 3:
        printf (": Daisy-chain too long (max. 8 devices)!\n");
        dump_hex_data_if_verbose (frame); 
        return 0;

      case 4:
        printf (": Soft overflow on incoming daisy-chain!\n");
        dump_hex_data_if_verbose (frame); 
        return 0;

      case 5:
        printf (": Hard overflow on incoming daisy-chain!\n");
        dump_hex_data_if_verbose (frame); 
        return 0;
  
      default:
        printf (": Unknown management data!\n");
        dump_hex_data (frame);
        return 0;
    }

  } else {
    // Multi-byte management frame
    switch (frame->data[0]) {
      case 6:
        // Test functions
        test_dispatch (frame, 1); // Frame subdata starts after the leading 6
        return 0;
      
      case 7:
        // DCC Out-of-band data
        if (frame->len != 2) {
          printf (": Unknown management data!\n");
          dump_hex_data (frame);
          return 0;
        }

        switch (frame->data[1]) {
          case 0:
            printf (": No longer filtering on DCC Accessory Decoder packets\n");
            dump_hex_data_if_verbose (frame);
            return 0;
            
          case 1:
            printf (": Filtering on DCC Accessory Decoder packets\n");
            dump_hex_data_if_verbose (frame);
            return 0;

          default:
            printf (": Unknown management data!\n");
            dump_hex_data (frame);
            return 0;
        }
        
      default:
        printf (": Unknown management data!\n");
        dump_hex_data (frame);
        return 0;
    }
  }
}
