/**
 * Definitions for the communication protocol of the DCC Monitor project PC
 * program.
 *
 * This file is part of DCC Monitor.
 *
 * Copyright 2007, 2008 Peter Lebbing <peter@digitalbrains.com>
 *
 * DCC Monitor is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * DCC Monitor is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DCC Monitor.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef FILE_SERIAL_COMM_PROTO_H
#define FILE_SERIAL_COMM_PROTO_H

#include <stdio.h>
#include "global.h"
#include "comm_proto.h"

/**
 * Return the total number of bytes read since startup
 */
extern unsigned int sercomm_get_byte_cnt ();

/**
 * Return the next frame from the input stream
 *
 * Return value is 0 for success, or:
 * END_INPUT: End of input stream reached
 * E_BIGFRAME: Frame received was too large
 * E_NULLFRAME: Just a frame start byte
 * E_TINYFRAME: Frame received was too small
 * E_PARITY: Frame failed parity check (frame parity != DCC parity!)
 */
extern comm_get_frame_function sercomm_get_frame;

/**
 * Set the given stream to be the input stream, which should be connected to the
 * DCC Monitor board.
 */
extern void sercomm_set_input_stream (FILE *stream);

#endif // ndef FILE_SERIAL_COMM_PROTO_H
