/**
 * Communication protocol routine emulation definitions
 *
 * The communication protocol routines of the firmware are emulated so they can
 * be used by tests copied from the firmware.
 *
 * The emulation only captures databytes written to a frame, the address and
 * protocol are don't-care.
 *
 * This file is part of DCC Monitor.
 *
 * Copyright 2007,2008 Peter Lebbing <peter@digitalbrains.com>
 *
 * DCC Monitor is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * DCC Monitor is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DCC Monitor.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef FILE_TESTS_COMM_EMUL_H
#define FILE_TESTS_COMM_EMUL_H

#include <stdint.h>
#include "../global.h"

/**
 * Emulation of firmware function comm_start_frame ()
 */
extern void comm_start_frame (const uint8_t proto);

/**
 * Emulation of firmware function comm_send_byte ()
 *
 * Precondition: appending this byte does not make the frame bigger than allowed
 * by MAX_FRAME_SIZE.
 */
extern void comm_send_byte (const char c);

/**
 * Emulation of firmware function comm_end_frame ()
 */
extern void comm_end_frame ();

/**
 * Set buffer for frame built during emulation
 */
extern void set_comm_emul_buf (struct s_frame *frame);

#endif // ndef FILE_TESTS_COMM_EMUL_H
